<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sqf="http://www.schematron-quickfix.com/validator/process">
	<ns prefix="tei" uri="http://www.tei-c.org/ns/1.0"/>
	<!--#############################-->
	<!--Qualitätskontrolle für die Rhodoman-Register-->
	<!--#############################-->
	<!--erstellt und gepflegt von Jennifer Bunselmeier (2022)-->
	<pattern id="bibl.att.id">
		<rule context="tei:bibl">
			<report test="contains(@xml:id, '/')" role="error">Mehrere Autoren in der ID durch "_" trennen, nicht durch "/".</report>
			<report test="matches(@xml:id, '[äöüß\(\)]')" role="error">In der ID keine Umlaute, Klammern etc. verwenden.</report>
		</rule>
	</pattern>
	<pattern id="spatien">
		<rule context="tei:bibl//tei:*[not(self::tei:abbr)] | tei:item//tei:*">
			<let name="name" value="name()"/>
			<report test="starts-with(., ' ')" role="warn" sqf:fix="deleteSSpace">Bitte prüfen: Spatium am Anfang des Elements "<value-of select="$name"/>" gefunden.</report>
			<report test="ends-with(., ' ')" role="warn" sqf:fix="deleteESpace">Bitte prüfen: Spatium am Ende des Elements "<value-of select="$name"/>" gefunden.</report>
			<sqf:fix id="deleteSSpace">
				<sqf:description>
					<sqf:title>Leerzeichen am Anfang löschen</sqf:title>
				</sqf:description>
				<sqf:stringReplace match="text()" regex="^ "/>
			</sqf:fix>
			<sqf:fix id="deleteESpace">
				<sqf:description>
					<sqf:title>Leerzeichen am Ende löschen</sqf:title>
				</sqf:description>
				<sqf:stringReplace match="text()" regex=" $"/>
			</sqf:fix>
		</rule>
	</pattern>
	<pattern id="expan">
		<rule context="tei:expan">
			<assert test="ends-with(., '.')" role="warn">Bitte prüfen: Vollständige Bibl. Angabe mit Punkt beenden.</assert>
		</rule>
	</pattern>
	<pattern id="gnd">
		<rule context="tei:seg[@type = 'gnd'][text()]">
			<assert test="matches(., '^[0-9A-Z-]*$')" role="error">Fehler im GND-Format (nur Zahlen, Buchstaben oder Trennstrich verwenden; keine Leerzeichen, Fragezeichen etc.).</assert>
		</rule>
	</pattern>
	<pattern id="item">
		<rule context="tei:item">
			<assert test="string(@type) and string(@subtype)" role="error">Type oder Subtype fehlen.</assert>
			<report test="matches(@xml:id, '[äöüß\(\)]')" role="error">In der ID keine Umlaute, Klammern etc. verwenden.</report>
			<report test="@type = 'person' and @subtype = 'none'" role="error">Bei Personen den @subtype präzise angeben, "none (NA)" ist nicht erlaubt.</report>
			<report test="(@type = 'place' or @type = 'subject') and not(@subtype = 'none')" role="error">Bei Geographica/Sachverhalt nur @subtype=none ("NA") erlaubt.</report>
		</rule>
	</pattern>
</schema>
