<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt3" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sqf="http://www.schematron-quickfix.com/validator/process" xmlns:tei="http://www.tei-c.org/ns/1.0">
	<ns prefix="tei" uri="http://www.tei-c.org/ns/1.0"/>
	<!--Qualitätskontrolle für die Rhodoman-Transkriptionen-->
	<!--erstellt und gepflegt von Jennifer Bunselmeier (2022)-->
	<!--
TODO:
- titleStmt/title type=file nur lat. Buchstaben
- evtl. prüfen, dass ID und Int. Kürzel übereinstimmen [Achtung: Punkt am Ende beachten und Ausgabe der Zahl abwarten/berücksichtigen
-->
	<!--..........................................-->
	<!--Globale Variablen-->
	<!--..........................................-->
	<let name="QMTrans" value="/tei:TEI[descendant::tei:change[@type = 'readyForQMTrans']]"/>
	<let name="creativePeriodContent" value="('Ilfelder Periode', 'Harburger Periode', 'Rostocker Periode', 'Schweriner Periode', 'Lüneburger Periode', 'Walkenrieder Periode', 'Jenaer Periode', 'Stralsunder Periode', 'Wittenberger Periode')"/>
	<let name="workPurposeContent" value="('Hauptwerk', 'Paratext', 'Private Kommunikation', 'Gelegenheitsdichtung')"/>
	<let name="literaryGenreContent" value="('Epos/Epyllion', 'Lehrgedicht', 'Panegyrisches Gedicht/Lobgedicht auf Personen', 'Lutherdichtung', 'Kulturgedicht (im Sinne der Reformation)', 'Totengedicht (mit jeweiligem Individualtitel)', 'Konsolatorisches Gedicht', 'Genesungsgedicht bzw. Dankgedicht zur Genesung', 'Hochzeitsgedicht', 'Geburtstagsgedicht', 'Glückwunschgedicht', 'Festgedicht', 'Dankgedicht', 'Abschiedsgedicht', 'Freundschaftsgesuch und Freundschaftsgedicht', 'Poetologisches Gedicht', 'Reisegedicht', 'Briefgedicht', 'Autobiographisches Gedicht', 'Beitragsgedicht', 'Widmungsgedicht', 'Funktionsgedicht von Universitätslehrern', 'Protreptisches Gedicht für Lernende', 'Paratext zu antiken Texten (Hypotheseis o.ä.)', 'Übersetzungsdichtung in bez. auf antike Autoren/klassische Texte', 'Anagramm', 'Kirchenlied', 'Bukolik', 'Brief (Prosa)')"/>
	<let name="autographContent" value="('Autograph', 'Abschrift')"/>
	<let name="respNames" value="('Stefan Weise', 'Thomas Gärtner', 'Jennifer Bunselmeier', 'Karen Lelittka', 'Christopher Loga')"/>
	<!--..........................................-->
	<!--Globale Keys-->
	<!--..........................................-->
	<xsl:key name="k-lineIDHash" match="//tei:l" use="concat('#', @xml:id)"><!--l/@xml:id (erweitert um #, zum Abgleich mit @corresp)--></xsl:key>
	<!--..........................................-->
	<!--Globale Message-Variablen-->
	<!--..........................................-->
	<diagnostics>
		<!--mEName: Name des rule-Elements ausgeben-->
		<diagnostic id="mEName">[<value-of select="name()"/>]</diagnostic>
		<!--mValues: Werteliste ausgeben ($values = Werteliste in Globalen Variablen s.o.; jew. in der rule aufgerufen)-->
		<diagnostic id="mValues">Erlaubte Werte: <value-of select="string-join($values, ', ')"/>.</diagnostic>
		<!--mJB: Meldung an JB ausgeben (Fehler evtl. aus word2tei-Transformation oder nur von JB behebbar)-->
		<diagnostic id="mJB">[An JB melden!]</diagnostic>
	</diagnostics>
	<!--..........................................-->
	<!--Hauptskript-->
	<!--..........................................-->
	<pattern id="front.spatien">
		<rule context="tei:front//tei:*[self::tei:p or self::tei:head]">
			<let name="name" value="name()"/>
			<report test="starts-with(., ' ')" role="warn" diagnostics="mEName">Bitte prüfen: Spatium gefunden am Anfang.</report>
			<report test="ends-with(., ' ')" role="warn" diagnostics="mEName">Bitte prüfen: Spatium gefunden am Ende.</report>
		</rule>
	</pattern>
	<pattern id="quoteInternal">
		<rule context="tei:title[@type = 'quoteInternal']">
			<let name="biblMs" value="/tei:TEI//tei:*[self::tei:biblStruct or self::tei:msDesc]"/>
			<let name="name" value="$biblMs/name()"/>
			<let name="sourceType" value="/tei:TEI//tei:sourceDesc/tei:*/name()"/>
			<let name="exceptions" value="('Frei.Eleg','Epist.1571-09-07.Chytr.Joh-Alb')"/>
			<!--Sicherstellen, dass Rhodoman entweder als Autor oder als Titel vorkommt (ausngenommen Arion und Frei.Eleg.)-->
			<report test="not(/tei:TEI/@xml:id = $exceptions) and not(tei:name[matches(., '^Rhod\.$')] or tei:title[matches(., '^Rhod\.$')])" role="warn">Bitte prüfen: "Rhod." fehlt - entweder als Autor/Sender/Empfänger (default) oder als Titel (falls Autor nicht Rhod.).</report>
			<!--Bei Briefen darauf achten, dass der Titel im Int.Kürzel "Epist." lautet und in biblStruct oder msDesc @subtype=letter vergeben ist-->
			<report test="tei:title[matches(., '^Epist\.$')] and not($biblMs/@subtype = 'letter')" role="error" diagnostics="mJB">Im Int. Kürzel wurde "Epist." (Brief) vergeben, aber in <value-of select="$name"/> fehlt der Subtyp "Brief".</report>
			<report test="not(tei:title[matches(., '^Epist\.$')]) and $biblMs/@subtype = 'letter'" role="error" diagnostics="mJB">Einheit wurde als Subtyp "Brief" markiert (in <value-of select="$name"/>), aber im Int. Kürzel fehlt der Titel "Epist.".</report>
			<report test="tei:title[matches(., '^Inscr\.')] and not($sourceType = 'listObject')" role="error" diagnostics="mJB">Im Int. Kürzel wurde "Inscr." (Inschrift) vergeben, aber sourceDesc ist "<value-of select="$sourceType"/>", nicht "listObject".</report>
			<report test="not(tei:title[matches(., '^Inscr\.')]) and $sourceType = 'listObject'" role="error" diagnostics="mJB">SourceDesc wurde als "listObject" markiert, aber im Int. Kürzel fehlt der Titel "Inscr.".</report>
		</rule>
	</pattern>
	<pattern id="quoteInternal2">
		<rule context="tei:title[@type = 'quoteInternal']/tei:*">
			<let name="reg1" value="'^\d{4}(-\d{2})?(-\d{2})?\.$'"/>
			<let name="reg2" value="'^sa(-\d{2})?(-\d{2})?\.$'"/>
			<let name="exceptions" value="('Rhod.Arion')"/>
			<report test="self::tei:title and matches(., '\. [a-zA-Z]')" role="warn">Bitte prüfen: Spatium gefunden zwischen Punkt und Buchstabe (normalerweise wird hier kein Spatium gesetzt).</report>
			<report test="self::tei:title and matches(., '\.\d')" role="warn">Bitte prüfen: Zahl folgt ohne Spatium auf einen Punkt (normalerweise wird hier ein Spatium gesetzt).</report>
			<report test="self::tei:date and not(matches(., $reg1) or matches(., $reg2))" role="error">Fehler im Datumsformat und/oder Punkt am Ende fehlt (erwartet: 0000-00-00. | 0000-00. | 0000. | sa-00-00. | sa-00. | sa.).</report>
			<report test="not(/tei:TEI/@xml:id = $exceptions) and not(matches(., '\.$') or matches(., '\d$'))" role="warn">Bitte prüfen: Angabe muss mit Punkt oder Zahl enden (Ausnahme ausgeschriebene Namen/Titel).</report>
		</rule>
	</pattern>
	<pattern id="anon">
		<rule abstract="true" id="compareRsQuoteInternal">
			<let name="quotInternalAnon" value="/tei:TEI//tei:title[@type = 'quoteInternal']/tei:name[@type eq $nameType][contains(., 'anon.')]"/>
			<!--Briefe: wenn Sender/Empfänger im Int.Kürzel als "anon." gekennzeichnet sind, darf in correspAction keine Indexreferenz vergeben sein (und umgekehrt)-->
			<report test="string(tei:rs/@ref) and $quotInternalAnon" role="error"><value-of select="$nameType"/>-ID vergeben (<value-of select="tei:rs/@ref"/>), aber im Int. Kürzel als "anon." angegeben. <value-of select="$quotInternalAnon"/></report>
			<report test="not(string(tei:rs/@ref)) and not($quotInternalAnon)" role="error">Keine <value-of select="$nameType"/>-ID vergeben, aber im Int. Kürzel als "<value-of select="/tei:TEI//tei:title[@type = 'quoteInternal']/tei:name[@type eq $nameType]"/>" angegeben (nicht "anon.").</report>
		</rule>
		<rule context="tei:correspAction[@type = 'sent']">
			<let name="nameType" value="'sender'"/>
			<extends rule="compareRsQuoteInternal"/>
		</rule>
		<rule context="tei:correspAction[@type = 'received']">
			<let name="nameType" value="'recipient'"/>
			<extends rule="compareRsQuoteInternal"/>
		</rule>
	</pattern>
	<pattern id="idno">
		<rule context="tei:biblStruct/tei:idno">
			<report test="not(string())" role="error">VD 16/17/18 Nr. fehlt. Falls es keine gibt, bitte das Feld über den Button löschen.</report>
			<report test="string() and starts-with(., 'VD')" role="error">VD16/17/18 Nummer nur als Nummer angeben, ohne einleitendes "VD 16".</report>
			<report test="string() and not(matches(., '\d'))" role="error">VD16/17/18 Nummer muss Zahlen enthalten. Nicht "deest" schreiben > dann Feld löschen.</report>
		</rule>
		<rule context="tei:object/tei:additional/tei:idno">
			<report test="not(string())" role="warn">Bitte prüfen: Feld nur leer lassen, wenn es keine DI Nr. gibt.</report>
			<report test="string() and not(matches(., '^Bd\. \d+, Nr\. \d+$'))" role="error">Fehler im DI-Format ("Bd. 0, Nr. 0").</report>
			<report test="string() and not(parent::tei:additional[tei:ref[@subtype='di'][string(@target)]])" subject="parent::tei:additional/tei:ref">DI-Nr. angegeben, aber Link zum DI-Datensatz fehlt.</report>
		</rule>
	</pattern>
	<pattern id="textClass.Count">
		<rule context="tei:textClass[@type = 'workPurpose']">
			<report test="tei:keywords[count(tei:term) &gt; 2]" role="warn">Bitte prüfen: Bei Werkgruppe sind mehr als 2 Werte angegeben, ist das sinnvoll?</report>
		</rule>
		<rule context="tei:textClass[@type = 'creativePeriod']">
			<report test="tei:keywords[count(tei:term) &gt; 1]" role="warn">Bitte prüfen: Bei Schaffensphase ist mehr als 1 Wert angegeben, ist das sinnvoll?</report>
		</rule>
	</pattern>
	<pattern id="textClass.Content">
		<!--In Werkgruppe, Schaffensphase und ed. Gattungszuordnung sind nur feste Werte erlaubt (Werteliste + Message s.o.)-->
		<rule abstract="true" id="checkValues">
			<report test="not(string())">Bitte einen Wert für <value-of select="$messageFragment"/> auswählen.</report>
			<report test="string() and not(text() = $values)" role="error" diagnostics="mValues mEName">Falscher Wert in <value-of select="$messageFragment"/>.</report>
		</rule>
		<rule context="tei:textClass[@type = 'workPurpose']/tei:keywords/tei:term">
			<let name="values" value="$workPurposeContent"/>
			<let name="messageFragment" value="'Werkgruppe'"/>
			<extends rule="checkValues"/>
		</rule>
		<rule context="tei:textClass[@type = 'creativePeriod']/tei:keywords/tei:term">
			<let name="values" value="$creativePeriodContent"/>
			<let name="messageFragment" value="'Schaffensphase'"/>
			<extends rule="checkValues"/>
		</rule>
		<rule context="tei:textClass[@type = 'literaryGenre']/tei:keywords/tei:term">
			<let name="values" value="$literaryGenreContent"/>
			<let name="messageFragment" value="'ed. Gattungszuordnung'"/>
			<extends rule="checkValues"/>
		</rule>
	</pattern>
	<pattern id="copies.complete">
		<rule context="tei:note[@type = 'copies']/tei:list/tei:item">
			<report test="tei:repository[text()] and not(tei:idno[text()])">Signatur fehlt.</report>
			<report test="tei:idno[text()] and not(tei:repository[text()])">Institution fehlt.</report>
		</rule>
	</pattern>
	<pattern id="autograph">
		<rule abstract="true" id="checkAutographContent">
			<let name="values" value="$autographContent"/>
			<assert test="text() = $values" role="error" diagnostics="mValues mEName">Bitte einen Wert auswählen (oder auf Fehler prüfen).</assert>
		</rule>
		<rule context="tei:physDesc/tei:handDesc">
			<extends rule="checkAutographContent"/>
		</rule>
		<!--bei Copies nur warnen, wenn ein Exemplar angegeben (= Text vorhanden) ist-->
		<rule context="tei:msDesc//tei:note[@type = 'copies']/tei:list/tei:item[descendant::tei:*/text()]/tei:p">
			<extends rule="checkAutographContent"/>
		</rule>
	</pattern>
	<pattern id="metDecl">
		<rule context="tei:metDecl//tei:item">
			<!--Stufe 1: Gedichtzuordnung vom Editor fehlt-->
			<assert test="string(@corresp)">Bitte die Sprach-/Metrikangaben einer Gedichtnr. zuordnen.</assert>
			<!--Stufe 2: Format prüfen [a) vor QM = einfache Zahl, b) nach QM = #d1]-->
			<report test="matches(@corresp, '\D') and not(matches(@corresp, '#d\d'))">Fehler im Format der Gedichtzuordnung (erwartet: einfache Zahl oder "#d[Zahl]").</report>
		</rule>
	</pattern>
	<pattern id="neologismenText">
		<rule context="tei:div[@type = 'listNeologisms']/tei:list[text()]">
			<report test="matches(., '\d ')" role="error">Leerzeichen nach Zahl löschen [Komma setzen, außer beim letzten Eintrag].</report>
		</rule>
	</pattern>
	<pattern id="TEI.att.id">
		<rule context="tei:TEI">
			<assert test="string(@xml:id)" role="error">Datei-ID fehlt.</assert>
			<report test="matches(@xml:id, ' ')" role="error">In der Datei-ID keine Leerzeichen verwenden.</report>
			<report test="matches(@xml:id, '\.$')" role="error">In der Datei-ID am Ende keinen Punkt setzen.</report>
		</rule>
	</pattern>
	<pattern id="note">
		<rule context="tei:note[@type = 'crit' or @type = 'similia']">
			<let name="reg1" value="'^\d+$'"/>
			<let name="reg2" value="'^\d+sq\.$'"/>
			<let name="reg3" value="'^\d+‒\d+$'"/>
			<let name="reg4" value="'^\d+–\d+$'"/>
			<!--15 (20.22)-->
			<let name="reg5" value="'^\d+ \(((\.)?\d+)+\)'"/> 
			<assert test="@n" role="error">@n in der Anmerkung fehlt.</assert>
			<assert test="matches(@n, $reg1) or matches(@n, $reg2) or matches(@n, $reg3) or matches(@n, $reg4) or matches(@n, $reg5)" role="warn" diagnostics="mJB">Bitte prüfen: Fehler im Nummernformat der Anm. Auch @corresp prüfen.</assert>
			<report test="matches(., '^\S*\]')" role="warn">Bitte prüfen: schließende Klammer am Anfang der Note gefunden.Wurde ein Lemma nicht korrekt kodiert?</report>
			<report test="matches(@corresp, '^#$') or matches(@corresp, '^$')" role="error">@corresp in der Anmerkung fehlt.</report>
			<assert test="
					every $corresp in tokenize(@corresp, ' ')
						satisfies exists(key('k-lineIDHash', $corresp))" diagnostics="mJB">Min. eine in @corresp referenzierte Vers-ID kann nicht gefunden werden.</assert>
		</rule>
		<rule context="tei:note[@type = 'footnote']">
			<assert test="@n" role="error">@n in der Anmerkung fehlt.</assert>
		</rule>
		<rule context="tei:note[@type = 'legalNotes']">
			<assert test="ancestor::tei:recording" role="error">note[legalNotes] nur innerhalb von recording erlaubt.</assert>
			<assert test="tei:note[@type = 'legalNotice']" diagnostics="mJB">In note[legalNotes] fehlt note[legalNotice].</assert>
			<assert test="tei:note[@type = 'rightsHolder']" diagnostics="mJB">In note[legalNotes] fehlt note[rightsHolder].</assert>
			<assert test="tei:date[@type = 'mediaCreated']" diagnostics="mJB">In note[legalNotes] fehlt date[mediaCreated].</assert>
		</rule>
		<rule context="tei:note[@type = 'rightsHolder']">
			<assert test="@subtype = 'private'" diagnostics="mJB">In note[rightsHolder] fehlt @subtype=private.</assert>
			<assert test="tei:persName[text()]">In note[rightsHolder] fehlt persName (oder persName ist leer).</assert>
		</rule>
	</pattern>
	<pattern id="seitenumbruch">
		<rule context="tei:div[@type = 'segment'][@xml:id = 'd1']">
			<assert test="tei:*[1][self::tei:pb]" role="error">Erstes Gedicht muss mit einer Seitenzahl beginnen.</assert>
		</rule>
		<rule context="tei:pb">
			<assert test="@n[matches(., '[a-zA-Z0-9]*')]" role="error">Seitenumbruch ist leer, bitte angeben.</assert>
		</rule>
	</pattern>
	<!--Auf Transformationsfehler prüfen -->
	<pattern id="text">
		<rule context="tei:*/text()">
			<report test="matches(., '\{') or matches(., '\}')" role="warn" diagnostics="mJB">Bitte prüfen: geschweifte Klammer gefunden > wurde ein Seitenumbruch nicht korrekt kodiert?</report>
			<report test="matches(., '@')" role="warn" diagnostics="mJB">Bitte prüfen: @-Zeichen gefunden > wurde ein Seitenumbruch nicht korrekt kodiert?</report>
			<report test="matches(., '&gt;')" role="warn" diagnostics="mJB">Bitte prüfen: Spitzklammer gefunden > wurde ein ###[supplied?] nicht korrekt kodiert?</report>
			<report test="matches(., '&lt;')" role="warn" diagnostics="mJB">Bitte prüfen: Spitzklammer gefunden > wurde ein ###[supplied?] nicht korrekt kodiert?</report>
			<report test="matches(., '\?') and ancestor::tei:teiHeader" role="warn">Bitte prüfen: Fragezeichen gefunden > muss hier noch etwas nachgetragen werden?</report>
		</rule>
	</pattern>
	<pattern id="text2">
		<rule context="tei:div[@type = 'transcript']//tei:seg[not(@type = 'translationOfMainText' or @type = 'translationOfMarginalia')]//tei:*/text()">
			<report test="matches(., '\[') or matches(., '\]')" role="warn">Bitte prüfen: eckige Klammer(n) gefunden > wurde ein ###[surplus?] nicht korrekt kodiert?</report>
		</rule>
	</pattern>
	<pattern id="distinct">
		<rule context="tei:body//tei:distinct">
			<assert test="tei:orig" role="error" diagnostics="mJB mEName">Im Neologismus fehlt das Element für die Originalschreibung.</assert>
			<assert test="tei:reg" role="error" diagnostics="mJB mEName">Im Neologismus fehlt das Element für die lemmatisierte Form.</assert>
			<assert test="string(tei:orig)" role="error" subject="tei:orig">Im Neologismus fehlt die Originalschreibung.</assert>
			<assert test="string(tei:reg)" role="error" subject="tei:reg">Im Neologismus fehlt die lemmatisierte Form.</assert>
			<assert test="count(tei:rs[@type = 'bibl']) eq 3" role="error">Im Neologismus werden genau 3 Literaturangaben erwartet.</assert>
		</rule>
		<rule context="$QMTrans//tei:back//tei:distinct">
			<report test="tei:rs[@subtype = 'not-checked']" role="warn">Bitte prüfen: Neologismus wurde noch nicht in allen Lexika überprüft.</report>
		</rule>
	</pattern>
	<pattern id="distinct.rs">
		<rule abstract="true" id="checkRs">
			<assert test="@ref = $refTypes" role="error">Lit.Ang. (<value-of select="@ref"/>) im Neologismus fehlerhaft (erlaubte Werte: <value-of select="string-join($refTypes, ', ')"/>).</assert>
		</rule>
		<rule context="tei:seg[@xml:lang = 'la']//tei:distinct/tei:rs">
			<let name="refTypes" value="('#hoven_2006', '#mlw_2019', '#tll_2009')"/>
			<extends rule="checkRs"/>
		</rule>
		<rule context="tei:seg[@xml:lang = 'grc' or @xml:lang = 'grc-dor']//tei:distinct/tei:rs">
			<let name="refTypes" value="('#lsj_1996', '#lampe_1961', '#lbg_2017')"/>
			<extends rule="checkRs"/>
		</rule>
	</pattern>
	<pattern id="transl.marginalia">
		<rule context="tei:l/tei:seg[@type = 'translationOfMarginalia']">
			<report test="@subtype = 'all' and parent::tei:l/tei:seg[@type = 'translationOfMarginalia'][not(@subtype = 'all')]" role="error">Subtype prüfen (Übersetzung gilt für alle Marginalien): es darf nicht zusätzlich Übersetzungen für konkrete Marginalien geben.</report>
			<report test="@subtype = 'mainText' and not(parent::tei:l/tei:seg[@type = 'translationOfMarginalia'][@subtype = 'translationOfMainText'])" role="error">Es gibt eine eigene Übersetzung zur Haupttextmarginalie, aber keine für die Nicht-Haupttextmarginalie.</report>
			<report test="@subtype = 'translationOfMainText' and not(parent::tei:l/tei:seg[@type = 'translationOfMarginalia'][@subtype = 'mainText'])" role="error">Es gibt eine eigene Übersetzung zur Nicht-Haupttextmarginalie, aber keine für die Haupttextmarginalie.</report>
		</rule>
	</pattern>
	<pattern id="transcriptAndTranslation.exists">
		<rule context="tei:l">
			<report test="tei:seg[@type = 'translationOfMainText'] and not(tei:seg[@type = 'mainText'])" role="error" diagnostics="mJB">Es fehlt der Haupttext zur Übersetzung.</report>
			<report test="tei:seg[@type = 'mainText'] and not(tei:seg[@type = 'translationOfMainText'])" role="error" diagnostics="mJB">Es fehlt die dt. Übersetzung des Haupttextes.</report>
			<report test="tei:seg[@type = 'translationOfMarginalia'] and not(tei:seg[@type = 'marginalia'])" role="error" diagnostics="mJB">Es fehlt die Marginalie zur Übersetzung.</report>
			<report test="tei:seg[@type = 'marginalia'] and not(tei:seg[@type = 'translationOfMarginalia'])" role="error" diagnostics="mJB">Es fehlt die dt. Übersetzung der Marginalie.</report>
		</rule>
	</pattern>
	<pattern id="structure.div.segment">
		<rule context="tei:div[@type = 'transcript']/tei:*">
			<report test="not(self::tei:div[@type = 'segment'])" role="error" diagnostics="mJB">In Transcript-Div wurde ein Element gefunden, das keine Segment-Div ist.</report>
		</rule>
	</pattern>
	<pattern id="structure.back.div">
		<rule context="tei:back">
			<assert test="tei:div[@type = 'footnotes']" role="error">Im back fehlt eine div (footnotes).</assert>
			<assert test="tei:div[@type = 'critNotes']" role="error">Im back fehlt eine div (critNotes).</assert>
			<assert test="tei:div[@type = 'similiaNotes']" role="error">Im back fehlt eine div (similiaNotes).</assert>
			<assert test="tei:div[@type = 'listSpondiaci']" role="error">Im back fehlt eine div (listSpondiaci).</assert>
			<assert test="tei:div[@type = 'listNeologisms']" role="error">Im back fehlt eine div (listNeologisms).</assert>
			<assert test="tei:div[@type = 'listIndexReferences']" role="error">Im back fehlt eine div (listIndexReferences).</assert>
			<assert test="tei:div[@type = 'listMonosyllaba']" role="error">Im back fehlt eine div (listMonosyllaba).</assert>
			<assert test="tei:div[@type = 'metadataDisplay']" role="error">Im back fehlt eine div (metadataDisplay).</assert>
			<assert test="tei:div[@type = 'metadataMetrics']" role="error">Im back fehlt eine div (metadataMetrics).</assert>
		</rule>
	</pattern>
	<pattern id="structure.back.list">
		<rule context="tei:back/tei:div[not(@type = 'index' or @type = 'quoteTitle')]/tei:list">
			<assert test="string(@corresp)" role="error">In back/list fehlt @corresp zum zugehörigen Gedicht.</assert>
			<assert test="@corresp[matches(., '#d\d') or matches(., '#front')]" role="error">Fehler im Format des back/list/@corresp (Format: "#d1" oder "#front").</assert>
		</rule>
	</pattern>
	<pattern id="structure.back.hasList">
		<rule context="tei:back/tei:div[@type = 'critNotes' or @type = 'similiaNotes' or @type = 'footnotes'][tei:*]">
			<assert test="tei:*[self::tei:list]" role="error" diagnostics="mJB">In back/div sind möglicherweise notes ohne list kodiert.</assert>
		</rule>
	</pattern>
	<pattern id="date.exists">
		<rule context="tei:msItem | tei:imprint | tei:additional">
			<assert test="tei:date[string(@when)]" role="error">Mindestens eine der drei Datumsangaben muss ausfgefüllt sein.</assert>
			<!--<assert test="tei:date[@type = 'objectCreated'][string(@when) or text()]" role="warn">Bitte prüfen: Entstehungsdatum des Objektes (Druckjahr o.Ä.) nicht angegeben.</assert>-->
			<!--<assert test="tei:date[@type = 'contentCreatedPresumed'][string(@when) or text()] or tei:date[@type = 'contentCreatedDocumented'][string(@when) or text()]" role="warn">Bitte prüfen: bei Entstehungsdatum Inhalt entweder "editorisch ermittelt" oder "im Original überliefert" ausfüllen (auch wenn identisch mit Objekt-Entstehungsdatum).</assert>-->
			<report test="tei:date[@type = 'contentCreatedPresumed'][string(@when) or text()] and tei:date[@type = 'contentCreatedDocumented'][string(@when) or text()]" role="warn">Bitte prüfen: Entstehungsdatum Inhalt sowohl "editorisch ermittelt" als auch "im Original überliefert" ausgefüllt, i.d.R. sollte nur ein Datum angegeben werden [Ausnahme: Editor vermutet Fehler im Originaldatum].</report>
		</rule>
	</pattern>
	<pattern id="date">
		<rule context="tei:msItem/tei:date[text()] | tei:imprint/tei:date[text()] | tei:additional/tei:date[text()]">
			<assert test="@when[matches(., '^\d{4}$')]" role="error">Technisches Jahr fehlt oder ist im falschen Format (erwartet: nur Jahreszahl).</assert>
		</rule>
		<rule context="tei:recording//tei:date">
			<assert test="@when[matches(., '^\d{4}-\d{2}-\d{2}$')]" role="error">Recording//date/@when im falschen Format (erwartet: 0000-00-00).</assert>
			<assert test="@type = 'mediaCreated'">In recording//date fehlt @type (oder falsch typisiert).</assert>
			<report test="text()">In recording//date kein Freitext erlaubt.</report>
		</rule>
	</pattern>
	<pattern id="seg">
		<rule context="tei:l/tei:seg">
			<let name="lang" value="@xml:lang"/>
			<let name="type" value="@type"/>
			<!-- <seg>-Typ nur einmal pro l erlaubt (ausgenommen Marg.Übersetzungen, weil es davon mehrere geben darf)-->
			<report test="not(@type = 'translationOfMarginalia') and preceding-sibling::tei:seg[@xml:lang = $lang][@type = $type]" role="warn">Bitte prüfen: es gibt bereits ein Segment mit diesem Typ und dieser Sprache.</report>
			<assert test="node()" role="error" diagnostics="mJB">Segment ist leer.</assert>
		</rule>
	</pattern>
	<pattern id="seg-spondaic">
		<rule context="tei:seg[@type = 'spondaic']">
			<report test="tei:seg" role="error" diagnostics="mJB">Spondiacus mehrfach geschachtelt.</report>
		</rule>
	</pattern>
	<pattern id="grcDor">
		<!--Prüfen, ob grc bzw. grc-dor einheitlich in metDecl, note und seg gesetzt wurden-->
		<rule context="tei:list/tei:note">
			<let name="list.corresp" value="ancestor::tei:list/@corresp"/>
			<report test="@xml:lang = 'grc-dor' and not(ancestor::tei:TEI//tei:metDecl//tei:item[@corresp = $list.corresp][descendant::tei:textLang[@mainLang = 'grc-dor']])" role="warn" diagnostics="mJB">"grc-dor" in Crit.Note kodiert, aber in der metDecl ist die Sprachangabe "grc-dor" nicht gegeben.</report>
			<report test="@subtype = 'grc-dor' and not(ancestor::tei:TEI//tei:metDecl//tei:item[@corresp = $list.corresp][descendant::tei:textLang[@mainLang = 'grc-dor']])" role="warn" diagnostics="mJB">"grc-dor" in Sim.Note kodiert, aber in der metDecl ist die Sprachangabe "grc-dor" nicht gegeben.</report>
		</rule>
		<rule context="tei:seg[@type = 'mainText' or @type = 'translationOfMainText' or @type = 'marginalia']">
			<let name="div.id" value="concat('#', ancestor::tei:div[@type = 'segment']/@xml:id)"/>
			<report test="@xml:lang = 'grc-dor' and not(ancestor::tei:TEI//tei:metDecl//tei:item[@corresp = $div.id][descendant::tei:textLang[@mainLang = 'grc-dor']])" role="warn" diagnostics="mJB">"grc-dor" in Segment kodiert, aber in der metDecl ist die Sprachangabe "grc-dor" nicht gegeben.</report>
			<report test="@xml:lang = 'grc' and ancestor::tei:TEI//tei:metDecl//tei:item[@corresp = $div.id][descendant::tei:textLang[@mainLang = 'grc-dor']]" role="warn" diagnostics="mJB">"grc" in Segment kodiert, aber in der metDecl ist die Sprachangabe "grc-dor" gegeben.</report>
		</rule>
	</pattern>
	<pattern id="seg.met.ana">
		<!--@MET:
Beispiele Hexameter: groß/klein:
- DDDDS-; DSDSDu
- dddds-; dsdsdu
Beispiele Pentameter: klein (vor QM): [mm= eigentlich Doppelminus, aber hier nicht darstellbar wegen Kommentar)]
- ddmm, dsmm, ds-u
Beispiele Pentameter nach QM:
- DD-DD-, DS-DD-, DS-DD-u
-->
		<!--@ANA: beliebig viele von:
#TH #PH #HH #BD #KTT #MZ
-->
		<!--A) @met (nach QM)-->
		<let name="reg1" value="'^[D|S]{5}[-|u]$'"/>
		<let name="reg2" value="'^[D|S]{2}[-|u]DD[-|u]$'"/>
		<let name="reg3" value="'^[d|s]{5}[-|u]$'"/>
		<let name="reg4" value="'^[d|s]{2}-[-|u]$'"/>
		<let name="reg5" value="'^(#TH ?|#PH ?|#HH ?|#BD ?|#KTT ?|#MZ)+$'"/>
		<let name="reg6" value="'^(th,?|ph,?|hh,?|bd,?|ktt,?|mz)+$'"/>
		<rule context="tei:seg/@met[matches(., 'D|S')]">
			<assert test="matches(., $reg1) or matches(., $reg2)" role="error">@met: Fehler im Metrikformat.</assert>
		</rule>
		<!--A) @met (vor QM)-->
		<rule context="tei:seg/@met[matches(., 'd|s')]">
			<assert test="matches(., $reg3) or matches(., $reg4)" role="error">@met: Fehler im Metrikformat.</assert>
		</rule>
		<!--B) @ana (nach QM)-->
		<rule context="tei:seg/@ana[matches(., '[A-Z]')]">
			<assert test="matches(., $reg5)" role="error">@ana: Fehler im Zäsurformat .</assert>
			<report test="matches(., '[A-Z]#')" role="error">@ana: Zäsueren durch Spatium trennen.</report>
			<report test="contains(., 'PH') and contains(., 'KTT')">@ana: Fehler im Zäsurformat (PH und KTT dürfen nicht zusammen vorkommen).</report>
		</rule>
		<!--B) @ana (vor QM)-->
		<rule context="tei:seg/@ana[matches(., '[a-z]')]">
			<assert test="matches(., $reg6)" role="error">@ana: Fehler im Zäsurformat (erlaubt: "th,ph,hh,bd,ktt,mz"; mehrere durch Komma trennen ohne Spatium).</assert>
		</rule>
		<!--C) <seg> sicherstellen, dass nach QM @met+@ana angereichert-->
		<rule context="tei:seg[string(@met) and string(@ana)]">
			<report test="@met[matches(., 'D|S')] and @ana[matches(., '[a-z]')]" diagnostics="mJB">Fehler nach QM (Kleinbuchstaben in @ana gefunden).</report>
			<report test="@met[matches(., 'd|s')] and @ana[matches(., '[A-Z]')]" diagnostics="mJB">Fehler nach QM (Kleinbuchstaben in @met gefunden).</report>
		</rule>
	</pattern>
	<pattern id="flagMissing">
		<rule context="tei:revisionDesc[ancestor::tei:TEI//tei:div[@type = 'transcript'][tei:*]]">
			<assert test="tei:change[@type = 'hasTranscript']" role="error" diagnostics="mJB">Transkriptionsflag fehlt.</assert>
		</rule>
	</pattern>
	<pattern id="change">
		<rule context="tei:change">
			<assert test="string(@when) and string(@who)" role="error">In der Flag fehlen das Datum und/oder der/die Verantwortliche.</assert>
			<report test="@type = 'update' and not(string())" role="error">In der Flag "Änderungen" fehlt eine kurze Beschreibung der Änderungen.</report>
			<report test="string() and not(@type = 'update')" role="error">Freitext in der Flag nicht erlaubt.</report>
			<report test="@type = 'readyForQMTrans' and not(parent::tei:revisionDesc[tei:change[@type = 'hasTranscript']])" role="error" diagnostics="mJB">Vor der Flag "QM (Transkription") muss die Flag "Basistranskription" gesetzt werden.</report>
			<report test="@type = 'readyForPublicationTrans' and not(parent::tei:revisionDesc[tei:change[@type = 'readyForQMTrans']])" role="error">Vor der Flag "Publikationsfreigabe (Transkription)" muss die Flag "QM (Transkription)" gesetzt werden.</report>
			<report test="@type = 'readyForPublicationTrans' and not(parent::tei:revisionDesc[tei:change[@type = 'readyForPublicationMeta']])" role="error">Vor der Flag "Publikationsfreigabe (Transkription)" muss die Flag "Publikationsfreigabe (Metadaten)" gesetzt werden.</report>
			<report test="@type = 'readyForPublicationMeta' and not(parent::tei:revisionDesc[tei:change[@type = 'readyForQMMeta']])" role="error">Vor der Flag "Publikationsfreigabe (Metadaten)" muss die Flag "QM (Metadaten)" gesetzt werden.</report>
			<report test="@type = 'update' and not(parent::tei:revisionDesc[tei:change[@type = 'readyForPublicationMeta' or @type = 'readyForPublicationTrans']])" role="error">Vor der Flag "Änderungen" muss die Flag "Publikationsfreigabe" (für Metadaten oder Transkription) gesetzt werden.</report>
		</rule>
	</pattern>
	<pattern id="biblScope">
		<rule context="tei:biblScope">
			<assert test="string()" role="error">Bitte Seitenabschnitt(e) angeben oder "Ganzschrift" auswählen.</assert>
		</rule>
	</pattern>
	<pattern id="dimensions.format">
		<rule context="tei:dimensions/tei:*[string()]">
			<!--Achtung: deutscher Zahlwert mit Komma, aber xs:decimal erlaubt nur die internationale Version mit Punkt, deshalb in Variable packen und für die Prüfung internationalisieren (Komma durch Punkt ersetzen)-->
			<let name="number" value="replace(string(), ',', '.')"/>
			<assert test="$number castable as xs:decimal" role="error">Maße als reinen Dezimalwert angeben (ohne Einheit, Spatien etc.).</assert>
		</rule>
	</pattern>
	<pattern id="objectDesc.p.Fußnoten">
		<rule context="tei:objectDesc/tei:p/text()">
			<report test="matches(., '\d\)')" role="warn">Bitte prüfen: Zahl gefolgt von Klammer gefunden > Wurde eine Fußnotennummer aus DI mitkopiert?</report>
		</rule>
	</pattern>
	<pattern id="textsprungmarke">
		<rule context="tei:div[@type = 'contentMilestones']//tei:ptr/@target">
			<!--Editor: 1.h.123-->
			<let name="reg1" value="'^\d\.[ghoc]\.\d\d*$'"/>
			<!--nach QM: #d1.h1.v123-->
			<let name="reg2" value="'^#d\d\.[ghoc]\d\.v\d\d*$'"/>
			<assert test="matches(., $reg1) or matches(., $reg2)" role="error">Fehler im Format der Zielvers-ID ("0.[h|g|o|c].0").</assert>
		</rule>
	</pattern>
	<pattern id="desc">
		<rule context="tei:div[@type = 'contentMilestones']//tei:desc">
			<assert test="@type">In Beschreibung der Textsprungmarke fehlt @type.</assert>
			<assert test="string()" role="error">Beschreibung der Textsprungmarke darf nicht leer sein.</assert>
			<report test="starts-with(., ' ') or ends-with(., ' ')" role="error">Spatium gefunden am Anfang/Ende der Beschreibung der Textsprungmarke.</report>
		</rule>
		<rule context="tei:media/tei:desc">
			<report test="@type">In media/desc ist kein @type erlaubt.</report>
		</rule>
	</pattern>
	<pattern id="media">
		<rule context="tei:media">
			<assert test="matches(@xml:id, '^audio-\d$')">Fehler in media/@xml:id (Format: "audio-1","audio-2",...).</assert>
			<report test="matches(@url, '^\.mp3$')">Fehler in media/@url (Dateiname fehlt vor ".mp3").</report>
			<assert test="matches(@url, '\.mp3$')">Fehler in media/@url (nur Dateiendung ".mp3" erlaubt).</assert>
		</rule>
	</pattern>
	<pattern id="respStmt">
		<rule context="tei:respStmt">
			<let name="values" value="$respNames"/>
			<report test="(@xml:id = 'edition' or @xml:id = 'additionalAnnotation' or @xml:id = 'encoding') and count(tei:persName) &gt; 1" role="error" diagnostics="mEName">Nicht mehr als ein Name (persName) erlaubt.</report>
		</rule>
	</pattern>
	<pattern id="respStmt.persName">
		<rule context="tei:respStmt/tei:persName">
			<let name="values" value="$respNames"/>
			<assert test="string(.)" role="error">Verantwortlicher fehlt.</assert>
			<report test="string(.) and not(text() = $values)" role="warn" diagnostics="mValues mEName">Fehler in Namensangabe der Verantwortlichen.</report>
		</rule>
	</pattern>
	<pattern id="respStmt.note">
		<rule context="tei:respStmt[@xml:id = 'additionalAnnotation']">
			<assert test="/tei:TEI//tei:note[@resp = '#additionalAnnotation']" role="error" diagnostics="mJB">respStmt additionalAnnotation kodiert, aber keine Note mit entsprechendem @resp versehen.</assert>
		</rule>
		<rule context="tei:note[@resp = '#additionalAnnotation']">
			<assert test="/tei:TEI//tei:respStmt[@xml:id = 'additionalAnnotation']" role="error" diagnostics="mJB">Anm. mit @resp=#additionalAnnotation kodiert, aber kein entsprechendes respStmt im Header.</assert>
		</rule>
	</pattern>
	<pattern id="respStmt.note2">
		<rule context="tei:note[@resp = '#additionalAnnotation'][@temp = 'sw']">
			<assert test="/tei:TEI//tei:respStmt[@xml:id = 'additionalAnnotation']/tei:persName[contains(., 'Stefan Weise')]" role="warn" diagnostics="mJB">In note/@temp ist SW festgehalten, aber es fehlt respStmt "Stefan Weise".</assert>
		</rule>
		<rule context="tei:note[@resp = '#additionalAnnotation'][@temp = 'tg']">
			<assert test="/tei:TEI//tei:respStmt[@xml:id = 'additionalAnnotation']/tei:persName[contains(., 'Thomas Gärtner')]" role="warn" diagnostics="mJB">In note/@temp ist TG festgehalten, aber es fehlt respStmt "Thomas Gärtner".</assert>
		</rule>
	</pattern>
	<pattern id="rs.index">
		<rule context="tei:rs[@type = 'index']">
			<report test="tei:*" role="error">Bitte prüfen: innerhalb von Indexreferenzen sind keine weiteren Auszeichnungen erlaubt (Neologismus, Spondiacus, Kursivierung etc. drum herum auszeichnen).</report>
			<report test="text() and not(string(@ref))" role="error">Index-ID fehlt.</report>
			<!--Freitext an einigen Stellen verboten-->
			<!--analytic/author
			imprint/pubPlace
			imprint/publisher
			item/pubPlace
			note[@type='relatedPersons']
			note[@type='relatedPlaces']
			correspAction
			back//item-->
			<report test="text() and parent::tei:*[self::tei:author[parent::tei:analytic] or self::tei:pubPlace or self::tei:publisher or self::tei:note[@type = 'relatedPersons' or @type = 'relatedPlaces'] or self::tei:correspAction or self::tei:item[ancestor::tei:back]]" role="warn">Bitte prüfen: bei Indexreferenzen an dieser Stelle keinen Freitext eingeben, nur ID-Referenz.</report>
			<!--Freitext an einigen Stellen verplichtend-->
			<!--monogr/author
			msItem/author
			history/provenance
			object//additional/author
			front//rs
			seg/rs [Achtung, gibt selten auch seg/hi/rs]-->
			<report test="string(@ref) and not(text()) and (parent::tei:*[self::tei:author[parent::tei:monogr or parent::tei:msItem or parent::tei:additional] or self::tei:provenance] or ancestor::tei:*[self::tei:seg or self::tei:front])" role="warn">Bitte prüfen: bei Indexreferenzen an dieser Stelle auch Freitext eingeben (Originalschreibweise).</report>
		</rule>
	</pattern>
	<pattern id="linkformat">
		<rule context="tei:ptr | tei:ref">
			<report test="@target[ends-with(., '.')]" role="error">Fehler im Linkformat (Punkt am Ende gefunden).</report>
			<report test="@target[contains(., ' ')]" role="error">Fehler im Linkformat (Leerzeichen gefunden).</report>
		</rule>
	</pattern>
	<pattern id="refInternal.verse">
		<rule context="tei:ref[@type = 'internal']">
			<report test="matches(., '\-')" role="error" sqf:fix="replaceMinus">Minus gefunden in Versangabe (statt Bis-Strich) - QUICKFIX. [Achtung: muss auch in Word korrigiert werden]</report>
			<sqf:fix id="replaceMinus">
				<sqf:description>
					<sqf:title>Minus in Bis-Strich ändern</sqf:title>
				</sqf:description>
				<sqf:stringReplace match="text()" regex="\-">‒</sqf:stringReplace>
			</sqf:fix>
		</rule>
	</pattern>
	<pattern id="refExternal">
		<rule context="tei:ref[@type = 'external']">
			<report test="(ancestor::tei:publicationStmt/tei:publisher or ancestor::tei:encodingDesc/tei:projectDesc/tei:p) and not(matches(., '^RHODOMANOLOGIA – Kritische Edition der griechischen und lateinischen Dichtungen von Lorenz Rhodoman$'))" role="error" diagnostics="mJB">Fehler im Editionstitel.</report>
		</rule>
	</pattern>
	<pattern id="pubPlace">
		<rule context="tei:pubPlace">
			<report test="ancestor::tei:publicationStmt and not(matches(., '^Wuppertal / Osnabrück$'))" role="error" diagnostics="mJB">Fehler im Publikationsort.</report>
		</rule>
	</pattern>
	<pattern id="hi">
		<rule context="tei:hi">
			<report test="tei:hi and not(ancestor::tei:div[@type = 'quoteTitle'])" role="error" diagnostics="mJB">Hi in Hi nicht erlaubt (außer in Kurztitelliste).</report>
		</rule>
	</pattern>
</schema>
